@@ -79,8 +79,10 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'BO', :name => 'Bolivia', :alpha3 => 'BOL', :numeric => '068' }, 
       { :alpha2 => 'BA', :name => 'Bosnia and Herzegovina', :alpha3 => 'BIH', :numeric => '070' }, 
       { :alpha2 => 'BW', :name => 'Botswana', :alpha3 => 'BWA', :numeric => '072' }, 
+      { :alpha2 => 'BV', :name => 'Bouvet Island', :alpha3 => 'BVD', :numeric => '074' }, 
       { :alpha2 => 'BR', :name => 'Brazil', :alpha3 => 'BRA', :numeric => '076' }, 
-      { :alpha2 => 'BN', :name => 'Brunei Darussalam', :alpha3 => 'BRN', :numeric => '096' }, 
+      { :alpha2 => 'BN', :name => 'Brunei Darussalam', :alpha3 => 'BRN', :numeric => '096' },
+      { :alpha2 => 'IO', :name => 'British Indian Ocean Territory', :alpha3 => 'IOT', :numeric => '086' }, 
       { :alpha2 => 'BG', :name => 'Bulgaria', :alpha3 => 'BGR', :numeric => '100' }, 
       { :alpha2 => 'BF', :name => 'Burkina Faso', :alpha3 => 'BFA', :numeric => '854' }, 
       { :alpha2 => 'BI', :name => 'Burundi', :alpha3 => 'BDI', :numeric => '108' }, 
@@ -93,6 +95,8 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'TD', :name => 'Chad', :alpha3 => 'TCD', :numeric => '148' }, 
       { :alpha2 => 'CL', :name => 'Chile', :alpha3 => 'CHL', :numeric => '152' }, 
       { :alpha2 => 'CN', :name => 'China', :alpha3 => 'CHN', :numeric => '156' }, 
+      { :alpha2 => 'CX', :name => 'Christmas Island', :alpha3 => 'CXR', :numeric => '162' }, 
+      { :alpha2 => 'CC', :name => 'Cocos (Keeling) Islands', :alpha3 => 'CCK', :numeric => '166' }, 
       { :alpha2 => 'CO', :name => 'Colombia', :alpha3 => 'COL', :numeric => '170' }, 
       { :alpha2 => 'KM', :name => 'Comoros', :alpha3 => 'COM', :numeric => '174' }, 
       { :alpha2 => 'CG', :name => 'Congo', :alpha3 => 'COG', :numeric => '178' }, 
@@ -122,6 +126,7 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'FR', :name => 'France', :alpha3 => 'FRA', :numeric => '250' }, 
       { :alpha2 => 'GF', :name => 'French Guiana', :alpha3 => 'GUF', :numeric => '254' }, 
       { :alpha2 => 'PF', :name => 'French Polynesia', :alpha3 => 'PYF', :numeric => '258' }, 
+      { :alpha2 => 'TF', :name => 'French Southern Territories', :alpha3 => 'ATF', :numeric => '260' }, 
       { :alpha2 => 'GA', :name => 'Gabon', :alpha3 => 'GAB', :numeric => '266' },
       { :alpha2 => 'GM', :name => 'Gambia', :alpha3 => 'GMB', :numeric => '270' }, 
       { :alpha2 => 'GE', :name => 'Georgia', :alpha3 => 'GEO', :numeric => '268' }, 
@@ -136,22 +141,26 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'GT', :name => 'Guatemala', :alpha3 => 'GTM', :numeric => '320' }, 
       { :alpha2 => 'GN', :name => 'Guinea', :alpha3 => 'GIN', :numeric => '324' }, 
       { :alpha2 => 'GW', :name => 'Guinea-Bissau', :alpha3 => 'GNB', :numeric => '624' }, 
-      { :alpha2 => 'GY', :name => 'Guyana', :alpha3 => 'GUY', :numeric => '328' }, 
+      { :alpha2 => 'GY', :name => 'Guyana', :alpha3 => 'GUY', :numeric => '328' },
+      { :alpha2 => 'GG', :name => 'Guernsey', :alpha3 => 'GGY', :numeric => '831' },
       { :alpha2 => 'HT', :name => 'Haiti', :alpha3 => 'HTI', :numeric => '332' }, 
       { :alpha2 => 'VA', :name => 'Holy See (Vatican City State)', :alpha3 => 'VAT', :numeric => '336' }, 
       { :alpha2 => 'HN', :name => 'Honduras', :alpha3 => 'HND', :numeric => '340' }, 
       { :alpha2 => 'HK', :name => 'Hong Kong', :alpha3 => 'HKG', :numeric => '344' }, 
+      { :alpha2 => 'HM', :name => 'Heard Island And Mcdonald Islands', :alpha3 => 'HMD', :numeric => '334' }, 
       { :alpha2 => 'HU', :name => 'Hungary', :alpha3 => 'HUN', :numeric => '348' }, 
       { :alpha2 => 'IS', :name => 'Iceland', :alpha3 => 'ISL', :numeric => '352' }, 
       { :alpha2 => 'IN', :name => 'India', :alpha3 => 'IND', :numeric => '356' }, 
       { :alpha2 => 'ID', :name => 'Indonesia', :alpha3 => 'IDN', :numeric => '360' }, 
       { :alpha2 => 'IR', :name => 'Iran, Islamic Republic of', :alpha3 => 'IRN', :numeric => '364' }, 
       { :alpha2 => 'IQ', :name => 'Iraq', :alpha3 => 'IRQ', :numeric => '368' }, 
-      { :alpha2 => 'IE', :name => 'Ireland', :alpha3 => 'IRL', :numeric => '372' }, 
+      { :alpha2 => 'IE', :name => 'Ireland', :alpha3 => 'IRL', :numeric => '372' },
+      { :alpha2 => 'IM', :name => 'Isle Of Man', :alpha3 => 'IMN', :numeric => '833' },  
       { :alpha2 => 'IL', :name => 'Israel', :alpha3 => 'ISR', :numeric => '376' }, 
       { :alpha2 => 'IT', :name => 'Italy', :alpha3 => 'ITA', :numeric => '380' }, 
       { :alpha2 => 'JM', :name => 'Jamaica', :alpha3 => 'JAM', :numeric => '388' }, 
       { :alpha2 => 'JP', :name => 'Japan', :alpha3 => 'JPN', :numeric => '392' }, 
+      { :alpha2 => 'JE', :name => 'Jersey', :alpha3 => 'JEY', :numeric => '832' }, 
       { :alpha2 => 'JO', :name => 'Jordan', :alpha3 => 'JOR', :numeric => '400' }, 
       { :alpha2 => 'KZ', :name => 'Kazakhstan', :alpha3 => 'KAZ', :numeric => '398' }, 
       { :alpha2 => 'KE', :name => 'Kenya', :alpha3 => 'KEN', :numeric => '404' }, 
@@ -181,11 +190,13 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'MQ', :name => 'Martinique', :alpha3 => 'MTQ', :numeric => '474' }, 
       { :alpha2 => 'MR', :name => 'Mauritania', :alpha3 => 'MRT', :numeric => '478' }, 
       { :alpha2 => 'MU', :name => 'Mauritius', :alpha3 => 'MUS', :numeric => '480' }, 
+      { :alpha2 => 'YT', :name => 'Mayotte', :alpha3 => 'MYT', :numeric => '175' }, 
       { :alpha2 => 'MX', :name => 'Mexico', :alpha3 => 'MEX', :numeric => '484' }, 
       { :alpha2 => 'FM', :name => 'Micronesia, Federated States of', :alpha3 => 'FSM', :numeric => '583' }, 
       { :alpha2 => 'MD', :name => 'Moldova, Republic of', :alpha3 => 'MDA', :numeric => '498' }, 
       { :alpha2 => 'MC', :name => 'Monaco', :alpha3 => 'MCO', :numeric => '492' }, 
       { :alpha2 => 'MN', :name => 'Mongolia', :alpha3 => 'MNG', :numeric => '496' }, 
+      { :alpha2 => 'ME', :name => 'Montenegro', :alpha3 => 'MNE', :numeric => '499' }, 
       { :alpha2 => 'MS', :name => 'Montserrat', :alpha3 => 'MSR', :numeric => '500' }, 
       { :alpha2 => 'MA', :name => 'Morocco', :alpha3 => 'MAR', :numeric => '504' }, 
       { :alpha2 => 'MZ', :name => 'Mozambique', :alpha3 => 'MOZ', :numeric => '508' }, 
@@ -207,6 +218,7 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'OM', :name => 'Oman', :alpha3 => 'OMN', :numeric => '512' }, 
       { :alpha2 => 'PK', :name => 'Pakistan', :alpha3 => 'PAK', :numeric => '586' }, 
       { :alpha2 => 'PW', :name => 'Palau', :alpha3 => 'PLW', :numeric => '585' }, 
+      { :alpha2 => 'PS', :name => 'Palestinian Territory, Occupied', :alpha3 => 'PSE', :numeric => '275' }, 
       { :alpha2 => 'PA', :name => 'Panama', :alpha3 => 'PAN', :numeric => '591' }, 
       { :alpha2 => 'PG', :name => 'Papua New Guinea', :alpha3 => 'PNG', :numeric => '598' }, 
       { :alpha2 => 'PY', :name => 'Paraguay', :alpha3 => 'PRY', :numeric => '600' }, 
@@ -221,9 +233,11 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'RO', :name => 'Romania', :alpha3 => 'ROM', :numeric => '642' }, 
       { :alpha2 => 'RU', :name => 'Russian Federation', :alpha3 => 'RUS', :numeric => '643' }, 
       { :alpha2 => 'RW', :name => 'Rwanda', :alpha3 => 'RWA', :numeric => '646' }, 
+      { :alpha2 => 'BL', :name => 'Saint Barthélemy', :alpha3 => 'BLM', :numeric => '652' }, 
       { :alpha2 => 'SH', :name => 'Saint Helena', :alpha3 => 'SHN', :numeric => '654' }, 
       { :alpha2 => 'KN', :name => 'Saint Kitts and Nevis', :alpha3 => 'KNA', :numeric => '659' }, 
       { :alpha2 => 'LC', :name => 'Saint Lucia', :alpha3 => 'LCA', :numeric => '662' }, 
+      { :alpha2 => 'MF', :name => 'Saint Martin (French part)', :alpha3 => 'MAF', :numeric => '663' }, 
       { :alpha2 => 'PM', :name => 'Saint Pierre and Miquelon', :alpha3 => 'SPM', :numeric => '666' }, 
       { :alpha2 => 'VC', :name => 'Saint Vincent and the Grenadines', :alpha3 => 'VCT', :numeric => '670' }, 
       { :alpha2 => 'WS', :name => 'Samoa', :alpha3 => 'WSM', :numeric => '882' }, 
@@ -231,6 +245,7 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'ST', :name => 'Sao Tome and Principe', :alpha3 => 'STP', :numeric => '678' }, 
       { :alpha2 => 'SA', :name => 'Saudi Arabia', :alpha3 => 'SAU', :numeric => '682' }, 
       { :alpha2 => 'SN', :name => 'Senegal', :alpha3 => 'SEN', :numeric => '686' }, 
+      { :alpha2 => 'RS', :name => 'Serbia', :alpha3 => 'SRB', :numeric => '688' }, 
       { :alpha2 => 'SC', :name => 'Seychelles', :alpha3 => 'SYC', :numeric => '690' }, 
       { :alpha2 => 'SL', :name => 'Sierra Leone', :alpha3 => 'SLE', :numeric => '694' }, 
       { :alpha2 => 'SG', :name => 'Singapore', :alpha3 => 'SGP', :numeric => '702' }, 
@@ -239,6 +254,7 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'SB', :name => 'Solomon Islands', :alpha3 => 'SLB', :numeric => '090' }, 
       { :alpha2 => 'SO', :name => 'Somalia', :alpha3 => 'SOM', :numeric => '706' }, 
       { :alpha2 => 'ZA', :name => 'South Africa', :alpha3 => 'ZAF', :numeric => '710' }, 
+      { :alpha2 => 'GS', :name => 'South Georgia and the South Sandwich Islands', :alpha3 => 'SGS', :numeric => '239' }, 
       { :alpha2 => 'ES', :name => 'Spain', :alpha3 => 'ESP', :numeric => '724' }, 
       { :alpha2 => 'LK', :name => 'Sri Lanka', :alpha3 => 'LKA', :numeric => '144' }, 
       { :alpha2 => 'SD', :name => 'Sudan', :alpha3 => 'SDN', :numeric => '736' }, 
@@ -252,6 +268,7 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'TJ', :name => 'Tajikistan', :alpha3 => 'TJK', :numeric => '762' }, 
       { :alpha2 => 'TZ', :name => 'Tanzania, United Republic of', :alpha3 => 'TZA', :numeric => '834' }, 
       { :alpha2 => 'TH', :name => 'Thailand', :alpha3 => 'THA', :numeric => '764' }, 
+      { :alpha2 => 'TL', :name => 'Timor Leste', :alpha3 => 'TLS', :numeric => '626' }, 
       { :alpha2 => 'TG', :name => 'Togo', :alpha3 => 'TGO', :numeric => '768' }, 
       { :alpha2 => 'TK', :name => 'Tokelau', :alpha3 => 'TKL', :numeric => '772' }, 
       { :alpha2 => 'TO', :name => 'Tonga', :alpha3 => 'TON', :numeric => '776' }, 
@@ -266,6 +283,7 @@ module ActiveMerchant #:nodoc:
       { :alpha2 => 'AE', :name => 'United Arab Emirates', :alpha3 => 'ARE', :numeric => '784' }, 
       { :alpha2 => 'GB', :name => 'United Kingdom', :alpha3 => 'GBR', :numeric => '826' }, 
       { :alpha2 => 'US', :name => 'United States', :alpha3 => 'USA', :numeric => '840' }, 
+      { :alpha2 => 'UM', :name => 'United States Minor Outlying Islands', :alpha3 => 'UMI', :numeric => '581' }, 
       { :alpha2 => 'UY', :name => 'Uruguay', :alpha3 => 'URY', :numeric => '858' }, 
       { :alpha2 => 'UZ', :name => 'Uzbekistan', :alpha3 => 'UZB', :numeric => '860' }, 
       { :alpha2 => 'VU', :name => 'Vanuatu', :alpha3 => 'VUT', :numeric => '548' }, 
