@@ -6,7 +6,7 @@ module ActiveMerchant #:nodoc:
           raise ArgumentError.new("Missing required parameter: #{param.first}") unless hash.has_key?(param.first) 
 
           valid_options = param[1..-1]
-          raise ArgumentError.new("Parameter: #{param.first} must be one of #{valid_options.to_sentence(:connector => 'or')}") unless valid_options.include?(hash[param.first])
+          raise ArgumentError.new("Parameter: #{param.first} must be one of #{valid_options.to_sentence(:words_connector => 'or')}") unless valid_options.include?(hash[param.first])
         else
           raise ArgumentError.new("Missing required parameter: #{param}") unless hash.has_key?(param) 
         end
