@@ -23,6 +23,10 @@ class BogusTest < Test::Unit::TestCase
   def test_credit
     @gateway.credit(1000, @response.params["transid"])
   end
+
+  def test_void
+    @gateway.void(@response.params["transid"])
+  end
   
   def  test_store
     @gateway.store(@creditcard)
